about summary refs log tree commit diff
diff options
context:
space:
mode:
authorUlrich Drepper <drepper@redhat.com>2001-04-22 14:12:27 +0000
committerUlrich Drepper <drepper@redhat.com>2001-04-22 14:12:27 +0000
commite661fdf2677bc45fa845da1c4c708d1ce56110e5 (patch)
tree801684576b6f33fe6af126c33ce39fc34c94e4ab
parentd20f21a2154de2960b13a67a6acfb78cc7cde13e (diff)
downloadglibc-e661fdf2677bc45fa845da1c4c708d1ce56110e5.tar.gz
glibc-e661fdf2677bc45fa845da1c4c708d1ce56110e5.tar.xz
glibc-e661fdf2677bc45fa845da1c4c708d1ce56110e5.zip
Update.
2001-04-22  Philip Blundell  <philb@gnu.org>

	* sysdeps/unix/sysv/linux/arm/sys/user.h (struct user_fpregs):
	Renamed from struct user_fp.
	(struct user_regs): New.
	(struct user): Use struct user_regs rather than struct pt_regs to
	avoid dependency on asm/ptrace.h.  Use struct user_fpregs in place
	of struct user_fp and struct user_fp_struct.
	* sysdeps/unix/sysv/linux/arm/sys/ucontext.h: Include sys/procfs.h
	not sys/elf.h.

2001-04-22  Philip Blundell  <philb@gnu.org>

	* sysdeps/unix/sysv/linux/arm/sys/elf.h: Move contents to
	sys/procfs.h, and tell the user to include that file instead.
	* sysdeps/unix/sysv/linux/arm/sys/procfs.h: Remove old cruft
	surrounded with #if 0.
	(elf_greg_t, ELF_NGREG, elf_gregset_t, elf_fpregset_t): Moved here
	from sys/elf.h.
	(prgregset_t, prfpregset_t): Define in terms of elf_gregset_t and
	elf_fpregset_t respectively.

2001-04-22  Philip Blundell  <philb@gnu.org>

	* sysdeps/unix/sysv/linux/arm/register-dump.h: Also print the
	address that faulted.
-rw-r--r--ChangeLog27
-rw-r--r--sysdeps/unix/sysv/linux/arm/register-dump.h11
-rw-r--r--sysdeps/unix/sysv/linux/arm/sys/elf.h10
-rw-r--r--sysdeps/unix/sysv/linux/arm/sys/procfs.h63
-rw-r--r--sysdeps/unix/sysv/linux/arm/sys/ucontext.h2
-rw-r--r--sysdeps/unix/sysv/linux/arm/sys/user.h26
6 files changed, 92 insertions, 47 deletions
diff --git a/ChangeLog b/ChangeLog
index a39a5f8ff7..4c7a9db35f 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,30 @@
+2001-04-22  Philip Blundell  <philb@gnu.org>
+
+	* sysdeps/unix/sysv/linux/arm/sys/user.h (struct user_fpregs):
+	Renamed from struct user_fp.
+	(struct user_regs): New.
+	(struct user): Use struct user_regs rather than struct pt_regs to
+	avoid dependency on asm/ptrace.h.  Use struct user_fpregs in place
+	of struct user_fp and struct user_fp_struct.
+	* sysdeps/unix/sysv/linux/arm/sys/ucontext.h: Include sys/procfs.h
+	not sys/elf.h.
+
+2001-04-22  Philip Blundell  <philb@gnu.org>
+
+	* sysdeps/unix/sysv/linux/arm/sys/elf.h: Move contents to
+	sys/procfs.h, and tell the user to include that file instead.
+	* sysdeps/unix/sysv/linux/arm/sys/procfs.h: Remove old cruft
+	surrounded with #if 0.
+	(elf_greg_t, ELF_NGREG, elf_gregset_t, elf_fpregset_t): Moved here
+	from sys/elf.h.
+	(prgregset_t, prfpregset_t): Define in terms of elf_gregset_t and
+	elf_fpregset_t respectively.
+
+2001-04-22  Philip Blundell  <philb@gnu.org>
+
+	* sysdeps/unix/sysv/linux/arm/register-dump.h: Also print the
+	address that faulted.
+
 2001-04-21  Ulrich Drepper  <drepper@redhat.com>
 
 	* sysdeps/generic/bits/confname.h: Add _SC_V6_* and _CS_POSIX_V6_*
diff --git a/sysdeps/unix/sysv/linux/arm/register-dump.h b/sysdeps/unix/sysv/linux/arm/register-dump.h
index 4ccd9e2e4c..25036df41d 100644
--- a/sysdeps/unix/sysv/linux/arm/register-dump.h
+++ b/sysdeps/unix/sysv/linux/arm/register-dump.h
@@ -1,5 +1,5 @@
 /* Dump registers.
-   Copyright (C) 1998, 1999 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2001 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Philip Blundell <pb@nexus.co.uk>, 1998.
 
@@ -32,6 +32,7 @@
  CPSR: XXXXXXXX
 
  Trap: XXXXXXXX   Error: XXXXXXXX   OldMask: XXXXXXXX
+ Addr: XXXXXXXX
 
  */
 
@@ -46,7 +47,7 @@ hexvalue (unsigned long int value, char *buf, size_t len)
 static void
 register_dump (int fd, union k_sigcontext *ctx)
 {
-  char regs[20][8];
+  char regs[21][8];
   struct iovec iov[97];
   size_t nr = 0;
 
@@ -105,6 +106,7 @@ register_dump (int fd, union k_sigcontext *ctx)
       hexvalue (ctx->v21.trap_no, regs[17], 8);
       hexvalue (ctx->v21.error_code, regs[18], 8);
       hexvalue (ctx->v21.oldmask, regs[19], 8);
+      hexvalue (ctx->v21.fault_address, regs[20], 8);
     }
 
   /* Generate the output.  */
@@ -148,6 +150,11 @@ register_dump (int fd, union k_sigcontext *ctx)
   ADD_MEM (regs[18], 8);
   ADD_STRING ("   OldMask: ");
   ADD_MEM (regs[19], 8);
+  if (ctx->v20.magic != SIGCONTEXT_2_0_MAGIC)
+    {
+      ADD_STRING ("\n Addr: ");
+      ADD_MEM (regs[20], 8);
+    }
 
   ADD_STRING ("\n");
 
diff --git a/sysdeps/unix/sysv/linux/arm/sys/elf.h b/sysdeps/unix/sysv/linux/arm/sys/elf.h
index 83658c3c27..ffd3b46ee6 100644
--- a/sysdeps/unix/sysv/linux/arm/sys/elf.h
+++ b/sysdeps/unix/sysv/linux/arm/sys/elf.h
@@ -1,4 +1,4 @@
-/* Copyright (C) 1996, 1997, 1999 Free Software Foundation, Inc.
+/* Copyright (C) 1996, 1997, 1999, 2001 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -19,12 +19,8 @@
 #ifndef _SYS_ELF_H
 #define _SYS_ELF_H	1
 
-#include <sys/user.h>
+#warning "This header is obsolete; use <sys/procfs.h> instead."
 
-typedef unsigned long int elf_greg_t;
-#define ELF_NGREG (sizeof (struct pt_regs) / sizeof(elf_greg_t))
-
-typedef elf_greg_t elf_gregset_t[ELF_NGREG];
-typedef struct user_fp 	elf_fpregset_t;
+#include <sys/procfs.h>
 
 #endif	/* sys/elf.h */
diff --git a/sysdeps/unix/sysv/linux/arm/sys/ucontext.h b/sysdeps/unix/sysv/linux/arm/sys/ucontext.h
index b858cf8c61..c94c6c6ba1 100644
--- a/sysdeps/unix/sysv/linux/arm/sys/ucontext.h
+++ b/sysdeps/unix/sysv/linux/arm/sys/ucontext.h
@@ -23,7 +23,7 @@
 
 #include <features.h>
 #include <signal.h>
-#include <sys/elf.h>
+#include <sys/procfs.h>
 
 typedef int greg_t;
 
diff --git a/sysdeps/unix/sysv/linux/arm/sys/user.h b/sysdeps/unix/sysv/linux/arm/sys/user.h
index 253b0f5ea9..e47c42c976 100644
--- a/sysdeps/unix/sysv/linux/arm/sys/user.h
+++ b/sysdeps/unix/sysv/linux/arm/sys/user.h
@@ -1,4 +1,4 @@
-/* Copyright (C) 1998, 1999 Free Software Foundation, Inc.
+/* Copyright (C) 1998, 1999, 2000, 2001 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -19,14 +19,11 @@
 #ifndef _SYS_USER_H
 #define _SYS_USER_H	1
 
-#include <features.h>
+/* The whole purpose of this file is for GDB and GDB only.  Don't read
+   too much into it.  Don't use it for anything other than GDB unless
+   you know what you are doing.  */
 
-/* <sys/ptrace.h> and <linux/ptrace.h> both define the PTRACE_* macros.
-   This leads to compilation problems with programs which include both
-   user.h and ptrace.h (eg: GDB).  Do not include <linux/ptrace.h> here. */
-#include <asm/ptrace.h>
-
-struct user_fp
+struct user_fpregs
 {
   struct fp_reg
   {
@@ -44,9 +41,14 @@ struct user_fp
   unsigned int init_flag;
 };
 
+struct user_regs
+{
+  unsigned long int uregs[18];
+};
+
 struct user
 {
-  struct pt_regs regs;		/* General registers */
+  struct user_regs regs;	/* General registers */
   int u_fpvalid;		/* True if math co-processor being used. */
 
   unsigned long int u_tsize;	/* Text segment size (pages). */
@@ -58,13 +60,13 @@ struct user
 
   long int signal;     		/* Signal that caused the core dump. */
   int reserved;			/* No longer used */
-  struct pt_regs *u_ar0;	/* help gdb to find the general registers. */
+  struct user_regs *u_ar0;	/* help gdb to find the general registers. */
 
   unsigned long magic;		/* uniquely identify a core file */
   char u_comm[32];		/* User command that was responsible */
   int u_debugreg[8];
-  struct user_fp u_fp;		/* Floating point registers */
-  struct user_fp_struct *u_fp0;	/* help gdb to find the FP registers. */
+  struct user_fpregs u_fp;	/* Floating point registers */
+  struct user_fpregs *u_fp0;	/* help gdb to find the FP registers. */
 };
 
 #endif  /* sys/user.h */
diff --git a/sysdeps/unix/sysv/linux/arm/sys/procfs.h b/sysdeps/unix/sysv/linux/arm/sys/procfs.h
index 5198033ba0..ddce965711 100644
--- a/sysdeps/unix/sysv/linux/arm/sys/procfs.h
+++ b/sysdeps/unix/sysv/linux/arm/sys/procfs.h
@@ -1,4 +1,4 @@
-/* Copyright (C) 1996, 1997, 1999 Free Software Foundation, Inc.
+/* Copyright (C) 1996, 1997, 1999, 2001 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -19,20 +19,36 @@
 #ifndef _SYS_PROCFS_H
 #define _SYS_PROCFS_H	1
 
 /* This is somehow modelled after the file of the same name on SysVr4
    systems.  It provides a definition of the core file format for ELF
-   used on Linux.  */
+   used on Linux.  It doesn't have anything to do with the /proc file
+   system, even though Linux has one.
+
+   Anyway, the whole purpose of this file is for GDB and GDB only.
+   Don't read too much into it.  Don't use it for anything other than
+   GDB unless you know what you are doing.  */
 
 #include <features.h>
-#include <signal.h>
 #include <sys/time.h>
 #include <sys/types.h>
-#include <sys/ucontext.h>
 #include <sys/user.h>
-#include <sys/elf.h>
 
 __BEGIN_DECLS
 
+/* Type for a general-purpose register.  */
+typedef unsigned long elf_greg_t;
+
+/* And the whole bunch of them.  We could have used `struct
+   user_regs' directly in the typedef, but tradition says that
+   the register set is an array, which does have some peculiar
+   semantics, so leave it that way.  */
+#define ELF_NGREG (sizeof (struct user_regs) / sizeof(elf_greg_t))
+typedef elf_greg_t elf_gregset_t[ELF_NGREG];
+
+/* Register set for the floating-point registers.  */
+typedef struct user_fpregs elf_fpregset_t;
+
+/* Signal info.  */
 struct elf_siginfo
   {
     int si_signo;			/* Signal number.  */
@@ -40,23 +56,19 @@ struct elf_siginfo
     int si_errno;			/* Errno.  */
   };
 
-/* Definitions to generate core files.  Fields present but not used are
-   marked with "XXX".  */
+/* Definitions to generate Intel SVR4-like core files.  These mostly
+   have the same names as the SVR4 types with "elf_" tacked on the
+   front to prevent clashes with Linux definitions, and the typedef
+   forms have been avoided.  This is mostly like the SVR4 structure,
+   but more Linuxy, with things that Linux does not support and which
+   GDB doesn't really use excluded.  */
+
 struct elf_prstatus
   {
-#if 0
-    long int pr_flags;			/* XXX Process flags.  */
-    short int pr_why;			/* XXX Reason for process halt.  */
-    short int pr_what;			/* XXX More detailed reason.  */
-#endif
     struct elf_siginfo pr_info;		/* Info associated with signal.  */
     short int pr_cursig;		/* Current signal.  */
     unsigned long int pr_sigpend;	/* Set of pending signals.  */
     unsigned long int pr_sighold;	/* Set of held signals.  */
-#if 0
-    struct sigaltstack pr_altstack;	/* Alternate stack info.  */
-    struct sigaction pr_action;		/* Signal action for current sig.  */
-#endif
     __pid_t pr_pid;
     __pid_t pr_ppid;
     __pid_t pr_pgrp;
@@ -65,15 +77,12 @@ struct elf_prstatus
     struct timeval pr_stime;		/* System time.  */
     struct timeval pr_cutime;		/* Cumulative user time.  */
     struct timeval pr_cstime;		/* Cumulative system time.  */
-#if 0
-    long int pr_instr;			/* Current instruction.  */
-#endif
     elf_gregset_t pr_reg;		/* GP registers.  */
     int pr_fpvalid;			/* True if math copro being used.  */
   };
 
 
-#define ELF_PRARGSZ     (80)    /* Number of chars for args */
+#define ELF_PRARGSZ     (80)    /* Number of chars for args.  */
 
 struct elf_prpsinfo
   {
@@ -90,18 +99,22 @@ struct elf_prpsinfo
     char pr_psargs[ELF_PRARGSZ];	/* Initial part of arg list.  */
   };
 
+/* The rest of this file provides the types for emulation of the
+   Solaris <proc_service.h> interfaces that should be implemented by
+   users of libthread_db.  */
+
 /* Addresses.  */
 typedef void *psaddr_t;
 
 /* Register sets.  Linux has different names.  */
-typedef gregset_t prgregset_t;
-typedef fpregset_t prfpregset_t;
+typedef elf_gregset_t prgregset_t;
+typedef elf_fpregset_t prfpregset_t;
 
 /* We don't have any differences between processes and threads,
-   therefore habe only ine PID type.  */
+   therefore have only one PID type.  */
 typedef __pid_t lwpid_t;
 
-
+/* Process status and info.  In the end we do provide typedefs for them.  */
 typedef struct elf_prstatus prstatus_t;
 typedef struct elf_prpsinfo prpsinfo_t;
 
@@ -19,20 +19,36 @@
 #define _SYS_PROCFS_H	1
 
-/* This is somehow modelled after the file of the same name on SysVr4
+/* This is somewhat modelled after the file of the same name on SVR4
    systems.  It provides a definition of the core file format for ELF